.. role:: hidden
    :class: hidden-section

ax.early_stopping
=================

.. automodule:: ax.early_stopping
.. currentmodule:: ax.early_stopping

Strategies
----------

Base Strategies
~~~~~~~~~~~~~~~

.. automodule:: ax.early_stopping.strategies.base
    :members:
    :undoc-members:
    :show-inheritance:

Logical Strategies
~~~~~~~~~~~~~~~~~~

.. automodule:: ax.early_stopping.strategies.logical
    :members:
    :undoc-members:
    :show-inheritance:

`PercentileEarlyStoppingStrategy`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.early_stopping.strategies.percentile
    :members:
    :undoc-members:
    :show-inheritance:

`ThresholdEarlyStoppingStrategy`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.early_stopping.strategies.threshold
    :members:
    :undoc-members:
    :show-inheritance:

Utils
-----

.. automodule:: ax.early_stopping.utils
    :members:
    :undoc-members:
    :show-inheritance:
